#include "config.h"

#include <sstream>
#include <stdexcept>

#include "QueryResultsIntervals.hh"

namespace diskCache
{
  QueryResultsIntervals::
  QueryResultsIntervals( format_type Format )
    : QueryResults( Format, TYPE_INTERVALS )
  {
  }

  void QueryResultsIntervals::
  Append( const std::string& Key,
	  gps_time Start,
	  gps_time Stop )
  {
    // static char caller[] = "diskCache::QueryResultsIntervals::AppendResults";

    interval_time_type& it = m_interval_raw[ Key ];

    if ( it.empty( ) )
    {
      it[ Start ] = Stop;
      return;
    }
    //-------------------------------------------------------------------
    // Find the lowerbound
    //-------------------------------------------------------------------
    interval_time_type::iterator lb( it.lower_bound( Start ) );
    if ( Start > lb->second )
    {
      //-----------------------------------------------------------------
      // Simply add this interval because it starts after the end of
      // the lowerbound interval.
      //-----------------------------------------------------------------
      lb = it.insert( lb, interval_time_type::value_type( Start, Stop ) );
    }
    else
    {
      //-----------------------------------------------------------------
      // Check to see if the current range needs to be expanded
      //-----------------------------------------------------------------
      if ( Stop > lb->second )
      {
	lb->second = Stop;
      }
      else
      {
	//---------------------------------------------------------------
	// Nothing was modified. So as to save time, just return.
	//---------------------------------------------------------------
	return;
      }
    }
    //-------------------------------------------------------------------
    // Need to check for merging of nodes
    //-------------------------------------------------------------------
    interval_time_type::iterator next( lb );

    if ( ++next != it.end( ) )
    {
      if ( lb->second >= next->first )
      {
	//---------------------------------------------------------------
	// Merge the nodes
	//---------------------------------------------------------------
	lb->second = next->second;
	it.erase( next );
      }
    }
    if ( lb != it.begin( ) )
    {
      interval_time_type::iterator prev( lb );
      --prev;

      if ( prev->second >= lb->first )
      {
	//---------------------------------------------------------------
	// Merge the nodes
	//---------------------------------------------------------------
	prev->second = lb->second;
	it.erase( lb );
      }
    }
  }

  void QueryResultsIntervals::
  Finalize( )
  {
    switch( format( ) )
    {
    case FORMAT_TCL:
      if ( m_interval_raw.empty( ) == false )
      {
	std::ostringstream	tcl_result;

	QueryResults::tcl_list_begin( tcl_result );
	for( interval_type::const_iterator
	       cur_interval = m_interval_raw.begin( ),
	       last_interval = m_interval_raw.end( );
	     cur_interval != last_interval;
	     ++cur_interval )
	{
	  tcl_result << " " << cur_interval->first;

	  QueryResults::tcl_list_begin( tcl_result );
	  for ( interval_time_type::const_iterator
		  cur_range = cur_interval->second.begin( ),
		  last_range = cur_interval->second.end( );
		cur_range != last_range;
		++cur_range )
	  {
	    tcl_result << " " << cur_range->first << " " << cur_range->second;
	  }

	  QueryResults::tcl_list_end( tcl_result );
	}
	QueryResults::tcl_list_end( tcl_result );
	m_string_result = tcl_result.str( );
      }
      break;
    default:
      // Do nothing
      break;
    }
  }
} // namespace - diskCache
