#ifndef DISKCACHE__QUERY_RESULTS_TIME_RANGE_HH
#define DISKCACHE__QUERY_RESULTS_TIME_RANGE_HH

#include <string>

#include "mountpt.hh"
#include "Query.hh"
#include "QueryResults.hh"
#include "timehash.hh"

namespace diskCache
{
  class QueryResultsTimeRange
    : public QueryResults
  {
  public:
    class RangeData;

    typedef void (*reconstitute_func_type)( Query::gps_time_type Start,
					    const RangeData* Data,
					    QueryResultsTimeRange& Results );

    class RangeData
    {
    public:
      RangeData( Query::gps_time_type Stop,
		 Query::gps_time_type Dt );

      virtual ~RangeData( );

      Query::gps_time_type DeltaT( ) const;

      Query::gps_time_type EndTime( ) const;

    private:
      const Query::gps_time_type	m_end_time;
      const Query::gps_time_type	m_delta_t;
    };

    typedef General::SharedPtr< RangeData >	range_data_type;

    QueryResultsTimeRange( format_type Foramt,
			   bool AllowGaps );

    virtual ~QueryResultsTimeRange( );

    void Append( const std::string& Filename );

    void Append( Query::gps_time_type Start,
		 reconstitute_func_type Func,
		 range_data_type Data );

    void Finalize( const Query& SearchParams );
    
    void Finalize( const Query& SearchParams,
		   TimeHash::KnownIntervals& NewData );

    bool Resample( Query& SearchParams ) const;
    void Swap( std::string& S1 );

  private:
    struct filename_info {
      reconstitute_func_type	s_func;
      range_data_type		s_data;

      filename_info( );

      filename_info( const filename_info& Source );

      filename_info( reconstitute_func_type	Func,
		     range_data_type		Data );

    };

    typedef std::map< Query::gps_time_type, filename_info > filename_info_container;

    static const Query::gps_time_type		m_RESAMPLE_PADDING;

    std::string					m_string_result;
    filename_info_container			m_file_data;
    bool					m_allow_gaps;
    std::string					m_conflicts;
  };

  inline void QueryResultsTimeRange::
  Append( const std::string& Filename )
  {
    if ( Filename.empty( ) )
    {
      return;
    }
    switch( format( ) )
    {
    case FORMAT_TCL:
      m_string_result += " ";
      m_string_result += Filename;
      break;
    case FORMAT_CONFLICT:
      throw MountPointHash::Conflict( Filename );
      break;
    default:
      // Do nothing
      break;
    }
  }

  inline void QueryResultsTimeRange::
  Swap( std::string& S1 )
  {
    m_string_result.swap( S1 );
  }

  inline QueryResultsTimeRange::RangeData::
  RangeData( Query::gps_time_type EndTime,
	     Query::gps_time_type DeltaT )
    : m_end_time( EndTime ),
      m_delta_t( DeltaT )
  {
  }

  inline Query::gps_time_type QueryResultsTimeRange::RangeData::
  DeltaT( ) const
  {
    return m_delta_t;
  }

  inline Query::gps_time_type QueryResultsTimeRange::RangeData::
  EndTime( ) const
  {
    return m_end_time;
  }

  inline QueryResultsTimeRange::filename_info::
  filename_info(  )
    : s_func( NULL ),
      s_data( NULL )
  {
  }

  inline QueryResultsTimeRange::filename_info::
  filename_info( const filename_info& Source )
    : s_func( Source.s_func ),
      s_data( Source.s_data )
  {
  }

  inline QueryResultsTimeRange::filename_info::
  filename_info( reconstitute_func_type	Func,
		 range_data_type Data )
    : s_func( Func ),
      s_data( Data )
  {
  }
} // namespace - diskCache

#endif /* DISKCACHE__QUERY_RESULTS_TIME_RANGE_HH */
