dnl ---------------------------------------------------------------------
dnl  Check for Support of md5sum calculations
dnl ---------------------------------------------------------------------
AC_DEFUN([AC_LDAS_CHECK_LIB_FRAMEL],[
  AC_LANG_SAVE
  AC_LANG_C
  ldas_saved_cflags=$CFLAGS
  ldas_saved_libs=$LIBS
  AC_ARG_WITH([framel],
  [ --with-framel=DIR   Directory where libframe exists],,
  [ for dir in /opt/lscsoft/libframe $prefix `echo $LD_LIBRARY_PATH | sed -e 's/:/ /g'`
    do
      dir="`echo $dir | sed -e 's/\/lib$//'`";
      if test -f "$dir/include/FrameL.h"
      then
        with_framel="$dir"
	break
      fi
    done ])

  case x$with_framel in
  x)
    ;;
  *)
    LIBS="$LIBS -L$with_framel/lib"
    ;;
  esac
  AC_CHECK_LIB(Frame,FrVectCompress,[
    AC_DEFINE(HAVE_LIBFRAME,1,Define to 1 if you have the `Frame' library (-lFrame))
    case x$with_framel in
    x)
      ;;
    *)
      LIBFRAME="-L$with_framel/lib "
      CPPFLAGSFRAME="-I$with_framel/include"
      ;;
    esac
    LIBFRAME="${LIBFRAME}-lFrame"
    LIBS="${lt_prog_compiler_static} ${LIBFRAME} -lm"
    CFLAGS="$CPPFLAGSFRAME $CFLAGS"
    AC_RUN_IFELSE([
	#include "FrameL.h"

	extern int FrSlong;

	int
	main( )
	{
	  FrLibShortIni( );
	  /*
	   * Zero exit (true) if FR_LONG_LONG should be defined
	   * Non-zero (false) if FR_LONG_LONG should not be defined
	   */
	  exit( FrSlong == sizeof( long ) );
	}
    ],[
      AC_DEFINE([DEFINE_FR_LONG_LONG],1,[Define to 1 if FR_LONG_LONG needs to be defined])
    ],[],[])

  ],[],-lm)
  AC_SUBST(LIBFRAME)
  AC_SUBST(CPPFLAGSFRAME)
  AM_CONDITIONAL(HAVE_LIBFRAME, test "x$LIBFRAME" != "x")
  CFLAGS=$ldas_saved_cflags
  LIBS=$ldas_saved_libs
  AC_LANG_RESTORE
])

dnl ---------------------------------------------------------------------
dnl  Check for Support of md5sum calculations
dnl ---------------------------------------------------------------------
AC_DEFUN([LDAS_LIB_MD5SUM],
  [ dnl -----------------------------------------------------------------
    dnl  Check for the library first
    dnl -----------------------------------------------------------------
    case `uname` in
    Linux)

      AC_CHECK_LIB(crypto,MD5_Init,
	[ AC_DEFINE(HAVE_MD5_IN_CRYPTO,1,[Defined if have md5 routines in libcrypto])
	  LIBMD5="-lcrypto"
	  AC_SUBST(LIBMD5)
          AC_CHECK_HEADERS([openssl/md5.h])
	],[ AC_CHECK_LIB(md5,MD5Init,
	    [ AC_DEFINE(HAVE_LIBMD5,1,[Defined if have libmd5])
	      LIBMD5="-lmd5"
	      AC_SUBST(LIBMD5)
	      AC_CHECK_HEADERS([md5.h])
	      AC_CHECK_HEADERS([md5global.h])
            ],[AC_MSG_ERROR(Missing md5 support) ])])
      ;;
    *)
      AC_CHECK_LIB(md5,MD5Init,
	[ AC_DEFINE(HAVE_LIBMD5,1,[Defined if have libmd5])
	  LIBMD5="-lmd5"
	  AC_SUBST(LIBMD5)
	  AC_CHECK_HEADERS([md5.h])
	  AC_CHECK_HEADERS([md5global.h])
	],[ AC_CHECK_LIB(crypto,MD5_Init,
	    [ AC_DEFINE(HAVE_MD5_IN_CRYPTO,1,[Defined if have md5 routines in libcrypto])
	      LIBMD5="-lcrypto"
	      AC_SUBST(LIBMD5)
              AC_CHECK_HEADERS([openssl/md5.h])
            ],[AC_MSG_ERROR(Missing md5 support) ])])
      ;;
    esac
  ])

dnl -------------------------------------------------------------------
dnl -- check for SGI STL library (to use instead of gcc provided one)
dnl -------------------------------------------------------------------
AC_DEFUN([LDAS_LIB_STLPORT],[
  dnl -----------------------------------------------------------------
  dnl --- STLport - Core library
  dnl -----------------------------------------------------------------
  AC_ARG_WITH([stlport],
  [ --with-stlport=DIR   Build with SGI STL library],,
  [ for dir in $prefix `echo $LD_LIBRARY_PATH | sed -e 's/:/ /g'`
    do
      dir="`echo $dir | sed -e 's/\/lib$//'`";
      if test -d "$dir/include/stlport"
      then
        with_stlport="$dir"
	break
      fi
    done ])
  AC_MSG_CHECKING(for stlport installation directory)
  case "x$with_stlport" in
  x|xno)
    AC_MSG_RESULT(none)
    ;;
  *)
    if test -d "$dir"/include/stlport
    then
      with_stlport="$dir"
      AC_MSG_RESULT($with_stlport/include/stlport)
      STLPORT_INCLUDE_DIR="$with_stlport/include/stlport"
      STLPORT_LIB_DIR="$with_stlport/lib"
      if test -e $STLPORT_LIB_DIR/libstlport_gcc.so
      then
        STLPORT_LIB="stlport_gcc"
        STLPORT_DEBUG_LIB="stlport_gcc_stldbg"
      else
        STLPORT_LIB="stlport"
        STLPORT_DEBUG_LIB="stlportg"
      fi
      STLPORT_DEBUG_CXXFLAGS="-D_STLP_DEBUG -D_STLP_DEBUG_ALLOC -D_STLP_DEBUG_UNINITIALIZED"
    else
      AC_MSG_ERROR( invalid stlport directory: $with_stlport )
    fi
    ;;
  esac
  dnl -------------------------------------------------------------------
  dnl -- check for debug STLport library
  dnl -------------------------------------------------------------------
  AC_ARG_ENABLE(stlport-debug,
  [ --enable-stlport-debug   Build with debug STL library],
  [enable_stlport_debug=yes],
  [enable_stlport_debug=no])
  dnl -------------------------------------------------------------------
  dnl -- Establish shell variable to know if using the debug version
  dnl -------------------------------------------------------------------
  case x"${with_stlport}" in
  x|xno)
    dnl -----------------------------------------------------------------
    dnl -- Either the installation directory was invalid or the user
    dnl --   specifically requested not to use STLport
    dnl -----------------------------------------------------------------
    ;;
  *)
    dnl -----------------------------------------------------------------
    dnl -- Want to use STLport
    dnl -----------------------------------------------------------------
    AC_MSG_CHECKING(for stlport debug)
    case x"${enable_stlport_debug}" in
    xyes)
      AC_MSG_RESULT(yes)
      case "${STLPORT_DEBUG_LIB}" in
        stlport_dbg)
        STLDEBUG="_dbg"
        ;;
      stlport_*_stldbg)
        STLDEBUG="_stldbg"
        ;;
      esac
      ;;
    *)
      dnl ---------------------------------------------------------------
      dnl Use non-debug version of stlport
      dnl ---------------------------------------------------------------
      AC_MSG_RESULT(no)
      ;;
    esac # x"${enable_stlport_debug}"
  esac # x"${enable_stlport}"
  dnl '''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
  dnl Set some compiler specific options
  dnl '''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
  if test "$ldas_prog_cxx_vendor" = Sun
  then
    if test -z "$STLPORT_LIB"
    then
      CXXFLAGS="$CXXFLAGS -library=stlport4"
    else
      CXXFLAGS="$CXXFLAGS -library=no%Cstd"
    fi
  fi
  AC_SUBST(STLDEBUG)
]) dnl LDAS_LIB_STLPORT

dnl ---------------------------------------------------------------------
dnl   Check for Support of STLport Finish
dnl ---------------------------------------------------------------------
AC_DEFUN([LDAS_LIB_STLPORT_FINISH],[
  dnl -------------------------------------------------------------------
  dnl -- Establish compiler/linker flags for STLport
  dnl -------------------------------------------------------------------
  case x"${with_stlport}" in
  x|xno)
    dnl -----------------------------------------------------------------
    dnl -- Either the installation directory was invalid or the user
    dnl --   specifically requested not to use STLport
    dnl -----------------------------------------------------------------
    ;;
  *)
    dnl -----------------------------------------------------------------
    dnl -- Want to use STLport
    dnl -----------------------------------------------------------------
    case x"${enable_stlport_debug}" in
    xyes)
      debug_flags="$STLPORT_DEBUG_CXXFLAGS"
      stlport_lib="STLPORT_DEBUG_LIB";
      ;;
    *)
      dnl ---------------------------------------------------------------
      dnl Use non-debug version of stlport
      dnl ---------------------------------------------------------------
      stlport_lib="$STLPORT_LIB";
      ;;
    esac # x"${enable_stlport_debug}"
    case x${STLPORT_CXXFLAGS} in
    x) ;;
    *) AC_MSG_CHECKING(for stlport CXXFLAGS)
       CXXFLAGS="${CXXFLAGS} ${STLPORT_CXXFLAGS}"
       AC_MSG_RESULT(${STLPORT_CXXFLAGS})
       ;;
    esac
    case x${STLPORT_INCLUDE_DIR} in
    x) ;;
    *) AC_MSG_CHECKING(for stlport include flags)
       CXXFLAGS="${CXXFLAGS} -I${STLPORT_INCLUDE_DIR} $debug_flags"
       AC_MSG_RESULT(-I${STLPORT_INCLUDE_DIR} $debug_flags)
       ;;
    esac
    case x${STLPORT_LIB_DIR} in
    x)
       case x${stlport_lib} in
       x)
 	 ;;
       *)
         STLPORT_LDFLAGS="-l${stlport_lib}"
         ;;
       esac
       ;;
    *)
       STLPORT_LDFLAGS="${LDFLAGS} -L${STLPORT_LIB_DIR} -l${stlport_lib}"
       ;;
    esac
    case x$STLPORT_LDFLAGS in
    x) ;;
    *) AC_MSG_CHECKING(for stlport LDFLAGS)
       LDFLAGS="${LDFLAGS} ${STLPORT_LDFLAGS}"
       AC_MSG_RESULT(${STLPORT_LDFLAGS})
       ;;
    esac
    ;;
  esac # x"${enable_stlport}"
])
dnl ---------------------------------------------------------------------
dnl  Check for Support of md5sum calculations
dnl ---------------------------------------------------------------------
AC_DEFUN([LDAS_LIB_UMEM],
[
  dnl -------------------------------------------------------------------
  dnl  Detect if the OS supplies a version of libumem
  dnl -------------------------------------------------------------------
  case x$enable_64bit in
  xyes)
    for x in 64 \
	sparcv9
    do
      if test -f /usr/lib/$x/libumem.so -o -L /usr/lib/$x/libumem.so
      then
        LIBUMEM=/usr/lib/$x/libumem.so
	break
      fi
    done
    ;;
  *)
    if test -f /usr/lib/libumem.so -o -L /usr/lib/libumem.so
    then
      LIBUMEM=/usr/lib/libumem.so
    fi
    ;;
  esac
  AC_SUBST(LIBUMEM)
])
